require "rexml/document"
require "open-uri"
require "fileutils"
require "kconv"

RTMPDUMP = "rtmpdump.exe"
FFMPEG   = "ffmpeg.exe"

URL_BASE ="rtmp://flv9.nhk.or.jp/flv9/_definst_/gogaku/streaming/flv"

XML_F = "listdataflv.xml"

COURSE_DATA = {
 "ek1" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/basic1"},
 "ek2" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/basic2"},
 "ek3" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/basic3"},
 "et5" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/training"},
 "er"  => {"base_url" => "http://www.nhk.or.jp/gogaku/english/kaiwa"},
 "ebn" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/business1"},
 "ebj" => {"base_url" => "http://www.nhk.or.jp/gogaku/english/business2"},
 "chi" => {"base_url" => "http://www.nhk.or.jp/gogaku/chinese/kouza"},
 "fra" => {"base_url" => "http://www.nhk.or.jp/gogaku/french/kouza"},
 "ita" => {"base_url" => "http://www.nhk.or.jp/gogaku/italian/kouza"},
 "kor" => {"base_url" => "http://www.nhk.or.jp/gogaku/hangeul/kouza"},
 "deu" => {"base_url" => "http://www.nhk.or.jp/gogaku/german/kouza"},
 "spa" => {"base_url" => "http://www.nhk.or.jp/gogaku/spanish/kouza"}
}

def exec_stub (cmd)
   system cmd
end

def usage
  print <<EOUSAGE
usage: get-flv.rb [course code]
  course code is one of the following:
    ek1 | bp1
    ek2 | bp2
    ek3 | bp3
    et5 | Tԃg[jO
    er  | WIpb
    ebn | rWlXp
    ebj | HrWlXp
    chi | ܂ɂ
    fra | ܂ɂtX
    ita | ܂ɂC^A
    kor | ܂ɂnOu
    deu | ܂ɂhCc
    spa | ܂ɂXyC

press [Enter] to close this window
EOUSAGE
if STDIN.gets then exit end
end

def get_flv(course_code)
  dir_n   = course_code
  xml_uri =  COURSE_DATA[course_code]["base_url"] +"/"+ XML_F
  xml = OpenURI.open_uri(xml_uri).read
  doc = REXML::Document.new xml
  doc.elements.each("musicdata/music") do |e|
    out_flv_dir = "flv/"+ dir_n
    unless( FileTest.exist? out_flv_dir ) then
      FileUtils.mkdir_p out_flv_dir
    end
    flv_n = e.attributes["file"]
    out_flv = out_flv_dir + "/" + flv_n
    unless( FileTest.exist? out_flv ) then
      cmd = RTMPDUMP + " -o #{out_flv} -r #{URL_BASE}/#{flv_n}"
      exec_stub cmd
    end

    if(FileTest.exist? out_flv) then
      out_mp3_dir = "mp3/" + dir_n
      unless( FileTest.exist? out_mp3_dir ) then
        FileUtils.mkdir_p out_mp3_dir
      end
      mp3_n = (e.attributes["kouza"] + " " + e.attributes["hdate"]).tosjis + ".mp3"
      out_mp3 = out_mp3_dir + "/" + mp3_n
      unless( FileTest.exist? out_mp3 ) then
        cmd = FFMPEG + " -i #{out_flv} -acodec copy \"#{out_mp3}\""
        exec_stub cmd
      end
    end
    sleep(1)
  end
end

if ARGV[0].nil? then
  usage
else
  get_flv(ARGV[0])
end
